
[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

1. [Overview](#overview)
2. [License](#license)
3. [Description - What the module does and why it is useful](#description)
4. [Setup](#setup)
  * [Requirements](#requirements)
  * [Installing the wls_config module](#installing-the-wls_config-module)
5. [Usage - Configuration options and additional functionality](#usage)
6. [Reference - An under-the-hood peek at what the module is doing and how](#reference)
7. [Limitations - OS compatibility, etc.](#limitations)

## Overview

This module allows you to configure and manage an Oracle WebLogic or Fusion middleware stack. It is part of our family of Puppet modules to install, manage and secure Oracle WebLogic and Fusion Middleware with Puppet. Besides the [`wls_config`](https://www.enterprisemodules.com/shop/products/puppet-wls_config-module?taxon_id=14) module, this family also contains:

- [wls_install](https://www.enterprisemodules.com/shop/products/puppet-wls_install-module?taxon_id=14) For installing an Oracle WebLogic and other Fusion products

## License

This is a commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/wls_config/license) for details.

## Description

The `wls_config` module extends the Puppet language to contain types needed to create and manage the lifecycle of objects within your Oracle Weblogic and Fusion Middleware installation. Instead of writing complex WLST scripts, using this module, you can now define your WebLogic configuration in an easy declarative way. 

The puppet `wls_config` module allows you to manage almost everything that is manageable in a WebLogic domain. For queue's and topics to datasources clusters and security policies. Here is a list of some of the objects you can manage with puppet when using this module:

- [`wls_setting`](https://www.enterprisemodules.com/docs/wls_config/wls_setting.html)
- [`wls_domain`](https://www.enterprisemodules.com/docs/wls_config/wls_domain.html)
- [`wls_deployment`](https://www.enterprisemodules.com/docs/wls_config/wls_deployment.html)
- [`wls_domain`](https://www.enterprisemodules.com/docs/wls_config/wls_domain.html)
- [`wls_user`](https://www.enterprisemodules.com/docs/wls_config/wls_user.html)
- [`wls_authentication_provider`](https://www.enterprisemodules.com/docs/wls_config/wls_authentication_provider.html)
- [`wls_identity_asserter`](https://www.enterprisemodules.com/docs/wls_config/wls_identity_asserter.html)
- [`wls_machine`](https://www.enterprisemodules.com/docs/wls_config/wls_machine.html)
- [`wls_server`](https://www.enterprisemodules.com/docs/wls_config/wls_server.html)
- [`wls_server_channel`](https://www.enterprisemodules.com/docs/wls_config/wls_server_channel.html)
- [`wls_cluster`](https://www.enterprisemodules.com/docs/wls_config/wls_cluster.html)
- [`wls_singleton_service`](https://www.enterprisemodules.com/docs/wls_config/wls_singleton_service.html)
- [`wls_coherence_cluster`](https://www.enterprisemodules.com/docs/wls_config/wls_coherence_cluster.html)
- [`wls_coherence_server`](https://www.enterprisemodules.com/docs/wls_config/wls_coherence_server.html)
- [`wls_server_template`](https://www.enterprisemodules.com/docs/wls_config/wls_server_template.html)
- [`wls_dynamic_cluster`](https://www.enterprisemodules.com/docs/wls_config/wls_dynamic_cluster.html)
- [`wls_virtual_host`](https://www.enterprisemodules.com/docs/wls_config/wls_virtual_host.html)
- [`wls_workmanager_constraint`](https://www.enterprisemodules.com/docs/wls_config/wls_workmanager_constraint.html)
- [`wls_workmanager`](https://www.enterprisemodules.com/docs/wls_config/wls_workmanager.html)
- [`wls_datasource`](https://www.enterprisemodules.com/docs/wls_config/wls_datasource.html)
- [`wls_file_persistence_store`](https://www.enterprisemodules.com/docs/wls_config/wls_file_persistence_store.html)
- [`wls_jdbc_persistence_store`](https://www.enterprisemodules.com/docs/wls_config/wls_jdbc_persistence_store.html)
- [`wls_jmsserver`](https://www.enterprisemodules.com/docs/wls_config/wls_jmsserver.html)
- [`wls_safagent`](https://www.enterprisemodules.com/docs/wls_config/wls_safagent.html)
- [`wls_jms_module`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_module.html)
- [`wls_jms_quota`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_quota.html)
- [`wls_jms_subdeployment`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_subdeployment.html)
- [`wls_jms_queue`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_queue.html)
- [`wls_jms_topic`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_topic.html)
- [`wls_jms_connection_factory`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_connection_factory.html)
- [`wls_jms_template`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_template.html)
- [`wls_saf_remote_context`](https://www.enterprisemodules.com/docs/wls_config/wls_saf_remote_context.html)
- [`wls_saf_error_handler`](https://www.enterprisemodules.com/docs/wls_config/wls_saf_error_handler.html)
- [`wls_saf_imported_destination`](https://www.enterprisemodules.com/docs/wls_config/wls_saf_imported_destination.html)
- [`wls_saf_imported_destination_object`](https://www.enterprisemodules.com/docs/wls_config/wls_saf_imported_destination_object.html)
- [`wls_foreign_server`](https://www.enterprisemodules.com/docs/wls_config/wls_foreign_server.html)
- [`wls_foreign_server_object`](https://www.enterprisemodules.com/docs/wls_config/wls_foreign_server_object.html)
- [`wls_mail_session`](https://www.enterprisemodules.com/docs/wls_config/wls_mail_session.html)
- [`wls_multi_datasource`](https://www.enterprisemodules.com/docs/wls_config/wls_multi_datasource.html)
- [`wls_jms_bridge_destination`](https://www.enterprisemodules.com/docs/wls_config/wls_jms_bridge_destination.html)
- [`wls_messaging_bridge`](https://www.enterprisemodules.com/docs/wls_config/wls_messaging_bridge.html)


Check [here](https://www.enterprisemodules.com/docs/wls_config/description.html) to see the full documentation for this module.

## Setup

### Requirements

The [`wls_config`](https://www.enterprisemodules.com/shop/products/puppet-wls_config-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 3.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- WebLogic 10g or higher
- A valid Oracle Weblogic or Fusion license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris
- Windows systems are **NOT** supported

We support WebLogic versions:

- WebLogic 10g
- WebLogic 11g
- WebLogic 12.1.2
- WebLogic 12.1.3
- WebLogic 12.2.1.2
- WebLogic 12.2.1.3

And Fusion versions:

- WebLogic 10g
- WebLogic 11g
- WebLogic 12c ( 12.1.1, 12.1.2, 12.1.3, 12.2.1.2 12.2.1.3)

### Installing the wls_config module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/wls_config'               ,'3.0.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-wls_config
```

## Usage

Building a total WebLogic or Fusion setup requires quite some work. To help you, we have built [some examples](https://github.com/enterprisemodules/simple_wls_demo). The repo contains a demonstration of a simple WebLogic installation. 

## Reference

Here you can find some more information regarding this puppet module:
- [The `wls_config` documentation](https://www.enterprisemodules.com/docs/wls_config/description.html)
- [The `wls_install` documentation](https://www.enterprisemodules.com/docs/wls_install/description.html)

Here are a related blog posts:
- [Introducing version 3 of wls_config](https://www.enterprisemodules.com/blog/2016/05/introducing-version-3-of-wls-config/)
- [Know thy WebLogic configuration using Puppet](https://www.enterprisemodules.com/blog/2016/01/know-thy-weblogic-configuration-using-puppet/)
- [Manage your WebLogic JMS config with Puppet](https://www.enterprisemodules.com/blog/2016/01/manage-your-weblogic-jms-config-with-puppet/)
- [Using Puppet to install and manage your WebLogic infrastructure](https://www.enterprisemodules.com/blog/2015/11/using-puppet-to-configure-your-weblogic-infrastructure/)

Some example code:
- [Simple WLS demo](https://github.com/enterprisemodules/simple_wls_demo)


## Limitations

This module runs on Solaris and most Linux versions. It requires a puppet version higher than 4. The module does **NOT** run on windows systems.
