---
title: wls coherence server
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a coherence server in an WebLogic domain.

Here is an example on how you should use this:

    wls_coherence_server { 'default':
      ensure         => 'present',
      server         => 'LocalMachine',
      unicastaddress => 'localhost',
      unicastport    => '8888',
    }

In this example you are managing a server in the default domain. When you want to
manage a coherence server in a specific domain, you can use:

    wls_coherence_server { 'my_domain/default':
      ensure         => 'present',
      server         => 'LocalMachine',
      unicastaddress => 'localhost',
      unicastport    => '8888',
    }

Check [the Oracle Weblogic documentation](https://docs.oracle.com/middleware/1212/coherence/COHMG/toc.htm)
for more documentation about setting up and managing a coherence server.

## Attributes



Attribute Name                                                                                 | Short Description                                                                                                               |
---------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------- |
[autorestart](#wls_coherence_server_autorestart)                                               | Specifies whether the Node Manager can automatically restart this server if it crashes or otherwise goes down unexpectedly.     |
[classpath](#wls_coherence_server_classpath)                                                   | The coherence machine classpath.                                                                                                |
[coherence_cluster_system_resource](#wls_coherence_server_coherence_cluster_system_resource)   | The system-level Coherence cluster resource associated with this server.                                                        |
[coherence_server_name](#wls_coherence_server_coherence_server_name)                           | The coherence server name.                                                                                                      |
[domain](#wls_coherence_server_domain)                                                         | With this parameter, you identify the domain, where your objects is in.                                                         |
[ensure](#wls_coherence_server_ensure)                                                         | The basic property that the resource should be in.                                                                              |
[machine](#wls_coherence_server_machine)                                                       | The machine of the server.                                                                                                      |
[name](#wls_coherence_server_name)                                                             | The name.                                                                                                                       |
[nm_socket_create_timeout_in_millis](#wls_coherence_server_nm_socket_create_timeout_in_millis) | Returns the timeout value to be used by NodeManagerRuntime when creating a socket connection to the agent.                      |
[notes](#wls_coherence_server_notes)                                                           | Optional information that you can include to describe this configuration.                                                       |
[provider](#wls_coherence_server_provider)                                                     | resource.                                                                                                                       |
[restart_delay_seconds](#wls_coherence_server_restart_delay_seconds)                           |  The number of seconds the Node Manager should wait before restarting this server.                                              |
[restart_interval_seconds](#wls_coherence_server_restart_interval_seconds)                     | The number of seconds during which this server can be restarted, up to the number of times specified in RestartMax.             |
[restart_max](#wls_coherence_server_restart_max)                                               | The number of times that the Node Manager can restart this server within the interval specified in RestartIntervalSeconds.      |
[restartdelay](#wls_coherence_server_restartdelay)                                             |  The number of seconds the Node Manager should wait before restarting this server.                                              |
[restartinterval](#wls_coherence_server_restartinterval)                                       | The number of seconds during which this server can be restarted, up to the number of times specified in RestartMax.             |
[restartmax](#wls_coherence_server_restartmax)                                                 | The number of times that the Node Manager can restart this server within the interval specified in RestartIntervalSeconds.      |
[start_arguments](#wls_coherence_server_start_arguments)                                       | The arguments to use when starting this server.                                                                                 |
[start_bea_home](#wls_coherence_server_start_bea_home)                                         | The BEA home directory (path on the machine running Node Manager) to use when starting this server.                             |
[start_class_path](#wls_coherence_server_start_class_path)                                     | The classpath (path on the machine running Node Manager) to use when starting this server.                                      |
[start_java_home](#wls_coherence_server_start_java_home)                                       | The Java home directory (path on the machine running Node Manager) to use when starting this server.                            |
[start_java_vendor](#wls_coherence_server_start_java_vendor)                                   | The Java Vendor value to use when starting this server.                                                                         |
[start_mw_home](#wls_coherence_server_start_mw_home)                                           | The MWHome directory (path on the machine running Node Manager) to use when starting this server.                               |
[start_notes](#wls_coherence_server_start_notes)                                               | Optional information that you can include to describe this configuration.                                                       |
[start_root_directory](#wls_coherence_server_start_root_directory)                             | The directory that this server uses as its root directory.                                                                      |
[start_tags](#wls_coherence_server_start_tags)                                                 | Return all tags on this Configuration MBean
                                                                                    |
[tags](#wls_coherence_server_tags)                                                             | Return all tags on this Configuration MBean
                                                                                    |
[unicast_listen_address](#wls_coherence_server_unicast_listen_address)                         | The IP address for the cluster unicast listener.                                                                                |
[unicast_listen_port](#wls_coherence_server_unicast_listen_port)                               | The port for the cluster unicast listener.                                                                                      |
[unicast_port_auto_adjust](#wls_coherence_server_unicast_port_auto_adjust)                     |  Specifies whether the unicast port will be automatically incremented if the port cannot be bound because it is already in use. |
[unicast_port_auto_adjust_attempts](#wls_coherence_server_unicast_port_auto_adjust_attempts)   |  Gets the upper bound of the unicast port.                                                                                      |
[unicastaddress](#wls_coherence_server_unicastaddress)                                         | The IP address for the cluster unicast listener.                                                                                |
[unicastport](#wls_coherence_server_unicastport)                                               | The port for the cluster unicast listener.                                                                                      |




### autorestart<a name='wls_coherence_server_autorestart'>

Specifies whether the Node Manager can automatically restart this server if it crashes or otherwise goes down unexpectedly.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       auto_restart => 1,
       ...
    }

Valid values are `absent`, `0`, `1`. 

[Back to overview of wls_coherence_server](#attributes)

### classpath<a name='wls_coherence_server_classpath'>

The coherence machine classpath.

Here is an example on how to use this:

    wls_coherence_server{ 'my_coherence_server':
      ...
      classpath => 'myClasspath',
      ...
    }



[Back to overview of wls_coherence_server](#attributes)

### coherence_cluster_system_resource<a name='wls_coherence_server_coherence_cluster_system_resource'>

The system-level Coherence cluster resource associated with this server.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       coherence_cluster_system_resource => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:coherence_cluster_system_resource']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### coherence_server_name<a name='wls_coherence_server_coherence_server_name'>

The coherence server name.

To identify a coherence server, use:

    wls_coherence_server{'domain_name/TheServerName':
    ...
    }



[Back to overview of wls_coherence_server](#attributes)

### domain<a name='wls_coherence_server_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_coherence_server](#attributes)

### ensure<a name='wls_coherence_server_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_coherence_server](#attributes)

### machine<a name='wls_coherence_server_machine'>

The machine of the server.

Here is an example on how to use this:

    wls_coherence_server{ 'my_coherence_server':
      ...
      machine => 'machine_1',
      ...
    }



[Back to overview of wls_coherence_server](#attributes)

### name<a name='wls_coherence_server_name'>

The name.



[Back to overview of wls_coherence_server](#attributes)

### nm_socket_create_timeout_in_millis<a name='wls_coherence_server_nm_socket_create_timeout_in_millis'>

Returns the timeout value to be used by NodeManagerRuntime when creating a socket connection to the agent. Default set high as SSH agent may require a high connection establishment time.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       nm_socket_create_timeout_in_millis => '180000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:nm_socket_create_timeout_in_millis']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### notes<a name='wls_coherence_server_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### provider<a name='wls_coherence_server_provider'>

The specific backend to use for this `wls_coherence_server`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage coherence server



[Back to overview of wls_coherence_server](#attributes)

### restart_delay_seconds<a name='wls_coherence_server_restart_delay_seconds'>

 The number of seconds the Node Manager should wait before restarting this server.    After killing a server process, the system might need several seconds to release the TCP port(s) the server was using. If Node Manager attempts to restart the Managed Server while its ports are still active, the startup attempt fails.    If AutoMigration is enabled and RestartDelaySeconds is 0, the RestartDelaySeconds is automatically set to the lease time. This prevents the server from failing to restart after migration when the previous lease is still valid.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       restart_delay_seconds => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:restart_delay_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### restart_interval_seconds<a name='wls_coherence_server_restart_interval_seconds'>

The number of seconds during which this server can be restarted, up to the number of times specified in RestartMax.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       restart_interval_seconds => '3600'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:restart_interval_seconds']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### restart_max<a name='wls_coherence_server_restart_max'>

The number of times that the Node Manager can restart this server within the interval specified in RestartIntervalSeconds.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       restart_max => '2'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:restart_max']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### restartdelay<a name='wls_coherence_server_restartdelay'>

 The number of seconds the Node Manager should wait before restarting this server.    After killing a server process, the system might need several seconds to release the TCP port(s) the server was using. If Node Manager attempts to restart the Managed Server while its ports are still active, the startup attempt fails.    If AutoMigration is enabled and RestartDelaySeconds is 0, the RestartDelaySeconds is automatically set to the lease time. This prevents the server from failing to restart after migration when the previous lease is still valid.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       restartdelay => 'a_value'
       ...
    }



[Back to overview of wls_coherence_server](#attributes)

### restartinterval<a name='wls_coherence_server_restartinterval'>

The number of seconds during which this server can be restarted, up to the number of times specified in RestartMax.

An example on how to use this:

   wls_coherence_server {a_wls_coherence_server :
      ...
      restartinterval => '3600'
      ...
   }



[Back to overview of wls_coherence_server](#attributes)

### restartmax<a name='wls_coherence_server_restartmax'>

The number of times that the Node Manager can restart this server within the interval specified in RestartIntervalSeconds.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       restartmax => '2'
       ...
    }



[Back to overview of wls_coherence_server](#attributes)

### start_arguments<a name='wls_coherence_server_start_arguments'>

The arguments to use when starting this server.  These are the first arguments appended immediately after <code>java</code> portion of the startup command. For example, you can set Java heap memory or specify any <code>weblogic.nodemanager.server.provider.WeblogicCacheServer</code> option.  Separate arguments with a space.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_arguments => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_arguments']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_bea_home<a name='wls_coherence_server_start_bea_home'>

The BEA home directory (path on the machine running Node Manager) to use when starting this server.  Specify the directory on the Node Manager machine under which all of Oracle's BEA products were installed. For example, <code>c:&#92Oracle&#92Middleware&#92</code>.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_bea_home => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_bea_home']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_class_path<a name='wls_coherence_server_start_class_path'>

The classpath (path on the machine running Node Manager) to use when starting this server.  If you need to add user classes to the classpath, in addition you will need to add the following: <code>FEATURES_HOME/weblogic.server.modules.coherence.server_10.3.4.0.jar:COHERENCE_HOME/lib/coherence.jar</code>  where <code>FEATURES_HOME</code> is the features directory (typically <code>$MW_HOME/modules/features</code>) and <code>COHERENCE_HOME</code> the coherence directory (typically <code>$MW_HOME/coherence_3.6</code>) on the Node Manager machine. If you do not specify a classpath the above will be used automatically.   The operating system determines which character separates path elements. On Windows, use a semicolon (;). On UNIX a colon (:).

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_class_path => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_class_path']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_java_home<a name='wls_coherence_server_start_java_home'>

The Java home directory (path on the machine running Node Manager) to use when starting this server.  Specify the parent directory of the JDK's <code>bin</code> directory. For example, <code>c:&#92;bea&#92;jdk141</code>.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_java_home => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_java_home']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_java_vendor<a name='wls_coherence_server_start_java_vendor'>

The Java Vendor value to use when starting this server.   If the server is part of a cluster and configured for automatic migration across possibly different platforms with different vendors providing the JDKs, then, both JavaVendor and JavaHome should be set in the generated configuration file instead.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_java_vendor => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_java_vendor']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_mw_home<a name='wls_coherence_server_start_mw_home'>

The MWHome directory (path on the machine running Node Manager) to use when starting this server.  Specify the directory on the Node Manager machine under which all of Oracle's MW products were installed. For example, <code>c:&#92;Oracle&#92;Middleware&#92;</code>.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_mw_home => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_mw_home']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_notes<a name='wls_coherence_server_start_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_root_directory<a name='wls_coherence_server_start_root_directory'>

The directory that this server uses as its root directory. This directory must be on the computer that hosts the Node Manager. If you do not specify a Root Directory value, the domain directory is used by default.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_root_directory => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_root_directory']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### start_tags<a name='wls_coherence_server_start_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       start_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:start_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### tags<a name='wls_coherence_server_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### unicast_listen_address<a name='wls_coherence_server_unicast_listen_address'>

The IP address for the cluster unicast listener. This attribute may be used to override the value of the referenced Coherence cluster.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       unicast_listen_address => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:unicast_listen_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### unicast_listen_port<a name='wls_coherence_server_unicast_listen_port'>

The port for the cluster unicast listener.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       unicast_listen_port => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:unicast_listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### unicast_port_auto_adjust<a name='wls_coherence_server_unicast_port_auto_adjust'>

 Specifies whether the unicast port will be automatically incremented if the port cannot be bound because it is already in use.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       unicast_port_auto_adjust => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:unicast_port_auto_adjust']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_coherence_server](#attributes)

### unicast_port_auto_adjust_attempts<a name='wls_coherence_server_unicast_port_auto_adjust_attempts'>

 Gets the upper bound of the unicast port. A positive value indicates the unicast port is automatically incremented if the specified port cannot be bound because it is already in use.

An example on how to use this:

    wls_coherence_server {a_wls_coherence_server :
       ...
       unicast_port_auto_adjust_attempts => '65535'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_coherence_server:unicast_port_auto_adjust_attempts']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_coherence_server](#attributes)

### unicastaddress<a name='wls_coherence_server_unicastaddress'>

The IP address for the cluster unicast listener. This attribute may be used to override the value of the referenced Coherence cluster.

Here is an example on using the unicast address on a coherence cluster. You can use an ip address like this:

    wls_coherence_cluster{'my_coherence_cluster':
      ...
      unicastaddress => '10.10.10.30',
      ...
    }

or use a host name like this:

    wls_coherence_cluster { 'aCluster':
      ...
      unicastaddress => 'myhost.exaqmple.com',
      ...
    }



[Back to overview of wls_coherence_server](#attributes)

### unicastport<a name='wls_coherence_server_unicastport'>

The port for the cluster unicast listener.

Here is an example on how to use this on a coherence cluster:

    wls_coherence_cluster{'my_coherence_cluster':
      ...
      unicastport => '9000',
      ...
    }



[Back to overview of wls_coherence_server](#attributes)
