---
title: wls jms subdeployment
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a JMS subdeployment in a JMS module of a WebLogic domain.

Here is an example on how you should use this:

    wls_jms_subdeployment { 'jmsClusterModule:jmsServers':
      ensure     => 'present',
      target     => ['jmsServer1','jmsServer2'],
      targettype => ['JMSServer','JMSServer'],
    }

In this example you are managing a JMS subdeployment in the default domain. When you want to
manage a JMS subdeployment in a specific domain, you can use:

    wls_jms_subdeployment { 'my_domain/jmsClusterModule:wlsServers':
      ensure     => 'present',
      target     => ['WebCluster'],
      targettype => ['Cluster'],
    }

## Attributes



Attribute Name                                                  | Short Description                                                                                                                           |
--------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------- |
[compatibility_name](#wls_jms_subdeployment_compatibility_name) |  This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean. |
[domain](#wls_jms_subdeployment_domain)                         | With this parameter, you identify the domain, where your objects is in.                                                                     |
[ensure](#wls_jms_subdeployment_ensure)                         | The basic property that the resource should be in.                                                                                          |
[jmsmodule](#wls_jms_subdeployment_jmsmodule)                   | The JMS module name.                                                                                                                        |
[module_type](#wls_jms_subdeployment_module_type)               | The values match those defined by jsr88.                                                                                                    |
[name](#wls_jms_subdeployment_name)                             | The name.                                                                                                                                   |
[notes](#wls_jms_subdeployment_notes)                           | Optional information that you can include to describe this configuration.                                                                   |
[provider](#wls_jms_subdeployment_provider)                     | resource.                                                                                                                                   |
[subdeployment_name](#wls_jms_subdeployment_subdeployment_name) | The subdeployment name
                                                                                                                     |
[tags](#wls_jms_subdeployment_tags)                             | Return all tags on this Configuration MBean
                                                                                                |
[target](#wls_jms_subdeployment_target)                         | An array of target names.                                                                                                                   |
[targettype](#wls_jms_subdeployment_targettype)                 | An array of target types.                                                                                                                   |
[timeout](#wls_jms_subdeployment_timeout)                       | Timeout for applying a resource.                                                                                                            |
[untargeted](#wls_jms_subdeployment_untargeted)                 | Only relevant for deployments in resource group templates.                                                                                  |




### compatibility_name<a name='wls_jms_subdeployment_compatibility_name'>

 This is only set for beans created as a result of conversion from an 8.1 application configured using ApplicationMBean and ComponentMBean.  Standalone modules in 8.1 have both an ApplicationMBean name and ComponentMBean name. This attribute stores the name of the latter, to be used when the server creates the transient ComponentMBean for backward compatibility.

An example on how to use this:

    wls_jms_subdeployment {a_wls_jms_subdeployment :
       ...
       compatibility_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_subdeployment:compatibility_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_subdeployment](#attributes)

### domain<a name='wls_jms_subdeployment_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_jms_subdeployment](#attributes)

### ensure<a name='wls_jms_subdeployment_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_jms_subdeployment](#attributes)

### jmsmodule<a name='wls_jms_subdeployment_jmsmodule'>

The JMS module name.



[Back to overview of wls_jms_subdeployment](#attributes)

### module_type<a name='wls_jms_subdeployment_module_type'>

The values match those defined by jsr88. This attribute may move to another MBean.

An example on how to use this:

    wls_jms_subdeployment {a_wls_jms_subdeployment :
       ...
       module_type => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_subdeployment:module_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_subdeployment](#attributes)

### name<a name='wls_jms_subdeployment_name'>

The name.



[Back to overview of wls_jms_subdeployment](#attributes)

### notes<a name='wls_jms_subdeployment_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jms_subdeployment {a_wls_jms_subdeployment :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_subdeployment:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_subdeployment](#attributes)

### provider<a name='wls_jms_subdeployment_provider'>

The specific backend to use for this `wls_jms_subdeployment`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage a JMS module of an WebLogic domain via regular WLST



[Back to overview of wls_jms_subdeployment](#attributes)

### subdeployment_name<a name='wls_jms_subdeployment_subdeployment_name'>

The subdeployment name



[Back to overview of wls_jms_subdeployment](#attributes)

### tags<a name='wls_jms_subdeployment_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_jms_subdeployment {a_wls_jms_subdeployment :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_subdeployment:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jms_subdeployment](#attributes)

### target<a name='wls_jms_subdeployment_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    ..{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_jms_subdeployment](#attributes)

### targettype<a name='wls_jms_subdeployment_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    ...{ 'aResource':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_jms_subdeployment](#attributes)

### timeout<a name='wls_jms_subdeployment_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_jms_subdeployment](#attributes)

### untargeted<a name='wls_jms_subdeployment_untargeted'>

Only relevant for deployments in resource group templates. Sub-deployments cannot have arbitrary targets if they are part of a deployment from resource group template. The sub-deployments, in such cases, may only be targeted to the virtual host of referring partition or stay untargeted. This flag, when specified with true, indicates that the sub-deployment must not be deployed in the referring partition

An example on how to use this:

    wls_jms_subdeployment {a_wls_jms_subdeployment :
       ...
       untargeted => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jms_subdeployment:untargeted']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jms_subdeployment](#attributes)
