---
title: wls jmsserver
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a jmsserver in an WebLogic domain.

Here is an example on how you should use this:

    wls_jmsserver { 'jmsServer1':
      ensure                      => 'present',
      persistentstore             => 'jmsFile1',
      persistentstoretype         => 'FileStore',
      target                      => ['wlsServer1'],
      targettype                  => ['Server'],
      allows_persistent_downgrade => '0',
      bytes_maximum               => '-1',
    }

In this example you are managing a JMS server in the default domain. When you want to
manage a JMS server in a specific domain, you can use:

    wls_jmsserver { 'my_domain/jmsServer2':
      ensure     => 'present',
      target     => ['wlsServer2'],
      targettype => ['Server'],
    }

## Attributes



Attribute Name                                                                          | Short Description                                                                                                                                                                |
--------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
[allows_persistent_downgrade](#wls_jmsserver_allows_persistent_downgrade)               | Specifies whether JMS clients will get an exception when sending persistent messages to a destination targeted to a JMS server that does not have a persistent store configured. |
[blocking_send_policy](#wls_jmsserver_blocking_send_policy)                             | Determines whether the JMS server delivers smaller messages before larger ones when a destination has exceeded its maximum number of messages.                                   |
[bytes_maximum](#wls_jmsserver_bytes_maximum)                                           | The maximum number of bytes that can be stored in this JMS server.                                                                                                               |
[bytes_paging_enabled](#wls_jmsserver_bytes_paging_enabled)                             | This parameter has been deprecated.                                                                                                                                              |
[bytes_threshold_high](#wls_jmsserver_bytes_threshold_high)                             | The upper threshold (number of bytes stored in this JMS server) that triggers flow control and logging events.                                                                   |
[bytes_threshold_low](#wls_jmsserver_bytes_threshold_low)                               | The lower threshold (number of bytes stored in this JMS server) that triggers flow control and logging events.                                                                   |
[consumption_paused_at_startup](#wls_jmsserver_consumption_paused_at_startup)           | Indicates whether consumption is paused at startup on destinations targeted to this JMS server at startup.                                                                       |
[deployment_order](#wls_jmsserver_deployment_order)                                     | A priority that the server uses to determine when it deploys an item.                                                                                                            |
[domain](#wls_jmsserver_domain)                                                         | With this parameter, you identify the domain, where your objects is in.                                                                                                          |
[ensure](#wls_jmsserver_ensure)                                                         | The basic property that the resource should be in.                                                                                                                               |
[expiration_scan_interval](#wls_jmsserver_expiration_scan_interval)                     | The number of seconds between this JMS server's cycles of scanning local destinations for expired messages.                                                                      |
[hosting_temporary_destinations](#wls_jmsserver_hosting_temporary_destinations)         | Specifies whether this JMS server can be used to host temporary destinations.                                                                                                    |
[insertion_paused_at_startup](#wls_jmsserver_insertion_paused_at_startup)               | Indicates whether insertion is paused at startup on destinations targeted to this JMS server.                                                                                    |
[jmsserver_name](#wls_jmsserver_jmsserver_name)                                         | The jmsserver_name name
                                                                                                                                                         |
[log_buffer_size_kb](#wls_jmsserver_log_buffer_size_kb)                                 | Gets the underlying log buffer size in kilobytes
                                                                                                                                |
[log_date_format_pattern](#wls_jmsserver_log_date_format_pattern)                       | The date format pattern used for rendering dates in the  log.                                                                                                                    |
[log_file_count](#wls_jmsserver_log_file_count)                                         | The maximum number of log files that the server creates when it rotates the log.                                                                                                 |
[log_file_min_size](#wls_jmsserver_log_file_min_size)                                   | The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file.                                                                               |
[log_file_name](#wls_jmsserver_log_file_name)                                           | The name of the file that stores current JMS server log messages.                                                                                                                |
[log_file_rotation_dir](#wls_jmsserver_log_file_rotation_dir)                           | The directory where the rotated log files will be stored.                                                                                                                        |
[log_file_time_span](#wls_jmsserver_log_file_time_span)                                 | The interval (in hours) at which the server saves old log messages to another file.                                                                                              |
[log_notes](#wls_jmsserver_log_notes)                                                   | Optional information that you can include to describe this configuration.                                                                                                        |
[log_number_of_files_limited](#wls_jmsserver_log_number_of_files_limited)               | Indicates whether to limit the number of log files that this server instance creates to store old messages.                                                                      |
[log_rotate_log_on_startup](#wls_jmsserver_log_rotate_log_on_startup)                   | Specifies whether a server rotates its log file during its startup cycle.                                                                                                        |
[log_rotation_time](#wls_jmsserver_log_rotation_time)                                   | Determines the start time (hour and minute) for a time-based rotation sequence.                                                                                                  |
[log_rotation_type](#wls_jmsserver_log_rotation_type)                                   | Criteria for moving old log messages to a separate file.                                                                                                                         |
[log_tags](#wls_jmsserver_log_tags)                                                     | Return all tags on this Configuration MBean
                                                                                                                                     |
[maximum_message_size](#wls_jmsserver_maximum_message_size)                             | The maximum number of bytes allowed in individual messages on this JMS server.                                                                                                   |
[message_buffer_size](#wls_jmsserver_message_buffer_size)                               | The amount of memory (in bytes) that this JMS server can use to store message bodies before it writes them to disk.                                                              |
[message_compression_options](#wls_jmsserver_message_compression_options)               | Specifies the type of message compression used when JMS message body compression is enabled for Persistent Stores and JMS Paging Stores.                                         |
[messages_maximum](#wls_jmsserver_messages_maximum)                                     | The maximum number of messages that can be stored in this JMS server.                                                                                                            |
[messages_paging_enabled](#wls_jmsserver_messages_paging_enabled)                       | This parameter has been deprecated.                                                                                                                                              |
[messages_threshold_high](#wls_jmsserver_messages_threshold_high)                       | The upper threshold (number of messages stored in this JMS server) that triggers flow control and logging events.                                                                |
[messages_threshold_low](#wls_jmsserver_messages_threshold_low)                         | The lower threshold (number of messages stored in this JMS server) that triggers flow control and logging events.                                                                |
[name](#wls_jmsserver_name)                                                             | The name.                                                                                                                                                                        |
[notes](#wls_jmsserver_notes)                                                           | Optional information that you can include to describe this configuration.                                                                                                        |
[paging_block_size](#wls_jmsserver_paging_block_size)                                   | The smallest addressable block, in bytes, of a file.                                                                                                                             |
[paging_directory](#wls_jmsserver_paging_directory)                                     |  Specifies where message bodies are written when the size of the message bodies in the JMS server exceeds the message buffer size.                                               |
[paging_file_locking_enabled](#wls_jmsserver_paging_file_locking_enabled)               | Determines whether OS file locking is used.                                                                                                                                      |
[paging_io_buffer_size](#wls_jmsserver_paging_io_buffer_size)                           | The I/O buffer size, in bytes, automatically rounded down to the nearest power of 2.                                                                                             |
[paging_max_file_size](#wls_jmsserver_paging_max_file_size)                             | The paging maximum file size, in bytes.                                                                                                                                          |
[paging_max_window_buffer_size](#wls_jmsserver_paging_max_window_buffer_size)           | The maximum amount of data, in bytes and rounded down to the nearest power of 2, mapped into the JVM's address space per paging store file.                                      |
[paging_message_compression_enabled](#wls_jmsserver_paging_message_compression_enabled) | Enables the JMS paging store to perform message body compression on persistent and non-persistent messages.                                                                      |
[paging_min_window_buffer_size](#wls_jmsserver_paging_min_window_buffer_size)           | The minimum amount of data, in bytes and rounded down to the nearest power of 2, mapped into the JVM's address space per paging store file.                                      |
[persistent_store](#wls_jmsserver_persistent_store)                                     | The file or database in which this JMS server stores persistent messages.                                                                                                        |
[persistentstore](#wls_jmsserver_persistentstore)                                       | The persistentstore name.                                                                                                                                                        |
[persistentstoretype](#wls_jmsserver_persistentstoretype)                               | The persistentstore type
                                                                                                                                                        |
[production_paused_at_startup](#wls_jmsserver_production_paused_at_startup)             | Specifies whether production is paused at server startup on destinations targeted to this JMS server.                                                                            |
[provider](#wls_jmsserver_provider)                                                     | resource.                                                                                                                                                                        |
[store_enabled](#wls_jmsserver_store_enabled)                                           | Specifies whether message persistence is supported for this JMS server.                                                                                                          |
[store_message_compression_enabled](#wls_jmsserver_store_message_compression_enabled)   | Enables the JMS store to perform message body compression.                                                                                                                       |
[tags](#wls_jmsserver_tags)                                                             | Return all tags on this Configuration MBean
                                                                                                                                     |
[target](#wls_jmsserver_target)                                                         | An array of target names.                                                                                                                                                        |
[targettype](#wls_jmsserver_targettype)                                                 | An array of target types.                                                                                                                                                        |
[temporary_template_name](#wls_jmsserver_temporary_template_name)                       | The name of a configured JMS template that this JMS server uses to create temporary destinations.                                                                                |
[temporary_template_resource](#wls_jmsserver_temporary_template_resource)               | The name of a JMS module that contains a template that this JMS server can use to create temporary destinations.                                                                 |
[timeout](#wls_jmsserver_timeout)                                                       | Timeout for applying a resource.                                                                                                                                                 |




### allows_persistent_downgrade<a name='wls_jmsserver_allows_persistent_downgrade'>

Specifies whether JMS clients will get an exception when sending persistent messages to a destination targeted to a JMS server that does not have a persistent store configured. This parameter only has effect when the Store Enabled parameter is disabled (false).  When set to false, the default, clients will get an exception when sending persistent messages to a JMS server with no store configured. When set to true, then persistent messages are downgraded to non-persistent; however, the send operations are allowed to continue.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       allows_persistent_downgrade => 1,
       ...
    }

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### blocking_send_policy<a name='wls_jmsserver_blocking_send_policy'>

Determines whether the JMS server delivers smaller messages before larger ones when a destination has exceeded its maximum number of messages. <code>FIFO</code> prevents the JMS server from delivering smaller messages when larger ones are already waiting for space. <code>Preemptive</code> allows smaller send requests to preempt previous larger ones when there is sufficient space for smaller messages on the destination.  This policy is defined only for the JMS server; it cannot be set on individual destinations.  Additional information on the <code>FIFO</code> and <code>Preemptive</code> policies is provided below.  <code>FIFO</code> (first in, first out) indicates that all send requests for the same destination are queued up one behind the other until space is available. No send request is permitted to successfully complete if there is another send request waiting for space before it. When space is limited, the FIFO policy prevents the starvation of larger requests because smaller requests cannot continuously use the remaining available space. Smaller requests are delayed, though not starved, until the larger request can be completed. When space does become available, requests are considered in the order in which they were made. If there is sufficient space for a given request, then that request is completed and the next request is considered. If there is insufficient space for a given request, then no further requests are considered until sufficient space becomes available for the current request to complete.  <code>Preemptive</code> indicates that a send operation can preempt other blocking send operations if space is available. That is, if there is sufficient space for the current request, then that space is used even if there are other requests waiting for space. When space is limited, the Preemptive policy can result in the starvation of larger requests. For example, if there is insufficient available space for a large request, then it is queued up behind other existing requests. When space does become available, all requests are considered in the order in which they were originally made. If there is sufficient space for a given request, then that request is allowed to continue and the next request is considered. If there is insufficient space for a given request, then that request is skipped and the next request is considered.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       blocking_send_policy => 'FIFO'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:blocking_send_policy']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### bytes_maximum<a name='wls_jmsserver_bytes_maximum'>

The maximum number of bytes that can be stored in this JMS server. A value of <code>-1</code> removes any WebLogic Server limits.  Because excessive bytes volume can cause memory saturation, Oracle recommends that this maximum corresponds to the total amount of system memory available after accounting for the rest of your application load.  Range of Values: &gt;= BytesThresholdHigh

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       bytes_maximum => '-1'
       ...
    }



[Back to overview of wls_jmsserver](#attributes)

### bytes_paging_enabled<a name='wls_jmsserver_bytes_paging_enabled'>

This parameter has been deprecated. Paging is always enabled. The "MessageBufferSize" parameter controls how much memory is used before paging kicks in.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       bytes_paging_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:bytes_paging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### bytes_threshold_high<a name='wls_jmsserver_bytes_threshold_high'>

The upper threshold (number of bytes stored in this JMS server) that triggers flow control and logging events. A value of <code>-1</code> disables the events for this JMS server.  The triggered events are: <ul> <li> <code>Log Messages</code> - A message is logged on the server indicating a high threshold condition. </li> <li> <code>Flow Control</code> - If flow control is enabled, the JMS server becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= BytesMaximum; &gt;= BytesThresholdLow

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       bytes_threshold_high => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:bytes_threshold_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### bytes_threshold_low<a name='wls_jmsserver_bytes_threshold_low'>

The lower threshold (number of bytes stored in this JMS server) that triggers flow control and logging events. A value of <code>-1</code> disables the events for this JMS server.  If the number of bytes falls below this threshold, the triggered events are: <ul> <li> <code>Log Messages</code> - A message is logged on the server indicating that the threshold condition has cleared. </li> <li> <code>Flow Control</code> - If flow control is enabled, the JMS server becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Range of Values: &lt;= BytesThresholdHigh

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       bytes_threshold_low => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:bytes_threshold_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### consumption_paused_at_startup<a name='wls_jmsserver_consumption_paused_at_startup'>

Indicates whether consumption is paused at startup on destinations targeted to this JMS server at startup. A destination cannot receive any new messages while it is paused.  When the value is set to <code>true</code>, then immediately after the host server instance is booted, then this JMS server and its targeted destinations are modified such that they are in a "consumption paused" state, which prevents any message consuming activity on those destinations.  To allow normal message consumption on the destinations, later you will have to change the state of this JMS server to a "consumption enabled" state by setting this value to <code>false</code>, and then either redeploy the JMS server or reboot the hosting server instance.  When the value is set to <code>default</code>, then the Consumption Paused At Startup is determined based on the corresponding setting on the individual destination.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       consumption_paused_at_startup => 'default'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:consumption_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### deployment_order<a name='wls_jmsserver_deployment_order'>

A priority that the server uses to determine when it deploys an item. The priority is relative to other deployable items of the same type.  For example, the server prioritizes and deploys all EJBs before it prioritizes and deploys startup classes.  Items with the lowest Deployment Order value are deployed first. There is no guarantee on the order of deployments with equal Deployment Order values. There is no guarantee of ordering across clusters.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       deployment_order => '1000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:deployment_order']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### domain<a name='wls_jmsserver_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_jmsserver](#attributes)

### ensure<a name='wls_jmsserver_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_jmsserver](#attributes)

### expiration_scan_interval<a name='wls_jmsserver_expiration_scan_interval'>

The number of seconds between this JMS server's cycles of scanning local destinations for expired messages. A value of <code>0</code> disables active scanning. A very large scan interval effectively disables active scanning.  With scanning disabled, users still do not receive expired messages and any expired messages that are discovered by other system activities are removed. However, expired messages sitting in idle destinations (such as an inactive queue or disconnected durable subscriber) are not removed and continue to consume system resources.  The scanning cycle for expired messages occurs as follows: <ul> <li> After the specified waiting period, the JMS server devotes a separate thread to scan all of its local destinations for expired messages. </li> <li> After the scanning is completed, all located expired messages are processed according to the specified Expiration Policy on the destination (Discard, Log, or Redirect). </li> <li> The entire process repeats after another specified waiting period. </li> </ul>  Note: Because a new scan does not start until the current one is finished and until the specified waiting period ends, an expired message could still remain in the system for the maximum scan waiting period plus the amount of time it takes to perform the scan.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       expiration_scan_interval => '30'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:expiration_scan_interval']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### hosting_temporary_destinations<a name='wls_jmsserver_hosting_temporary_destinations'>

Specifies whether this JMS server can be used to host temporary destinations.  If this field is enabled and no Temporary Template Name is defined, then the temporary destinations created on this JMS server will use all default destination values. If this field is enabled, then the JMS template to be used for creating temporary destinations is specified by the Temporary Template Name field. If this field is disabled, then this JMS server will not host temporary destinations.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       hosting_temporary_destinations => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:hosting_temporary_destinations']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### insertion_paused_at_startup<a name='wls_jmsserver_insertion_paused_at_startup'>

Indicates whether insertion is paused at startup on destinations targeted to this JMS server. A destination cannot receive any new messages while it is paused.  When the value is set to <code>true</code>, then immediately after the host server instance is booted, then this JMS server and its targeted destinations are modified such that they are in a "insertion paused" state, which results preventing messages that are result of the "in-flight" work completion to arrive on those destinations.  Note: For a detailed definition of "in-flight" work/messages, see weblogic.management.runtime.JMSServerRuntimeMBean#resumeInsertion and weblogic.management.runtime.JMSDestinationRuntime#resumeInsertion  To allow in-flight work messages to appear on the destinations, later you will have to change the state of this JMS server to an "insertion enabled" state by setting this value to <code>false</code>, and then either redeploy the JMS server or reboot the hosting server instance.  When the value is set to <code>default</code>, then the Insertion Paused At Startup is determined based on the corresponding setting on the individual destination.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       insertion_paused_at_startup => 'default'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:insertion_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### jmsserver_name<a name='wls_jmsserver_jmsserver_name'>

The jmsserver_name name



[Back to overview of wls_jmsserver](#attributes)

### log_buffer_size_kb<a name='wls_jmsserver_log_buffer_size_kb'>

Gets the underlying log buffer size in kilobytes

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_buffer_size_kb => '8'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_buffer_size_kb']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_date_format_pattern<a name='wls_jmsserver_log_date_format_pattern'>

The date format pattern used for rendering dates in the  log. The DateFormatPattern string conforms to the specification of the <code>java.text.SimpleDateFormat</code> class.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_date_format_pattern => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_date_format_pattern']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_file_count<a name='wls_jmsserver_log_file_count'>

The maximum number of log files that the server creates when it rotates the log. This number does not include the file that the server uses to store current messages. (Requires that you enable Number of Files Limited.)

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_file_count => '7'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_file_count']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_file_min_size<a name='wls_jmsserver_log_file_min_size'>

The size (1 - 2097150 kilobytes) that triggers the server to move log messages to a separate file. The default is 500 kilobytes. After the log file reaches the specified minimum size, the next time the server checks the file size, it will rename the current log file as <code>SERVER_NAME.lognnnnn</code> and create a new one to store subsequent messages. (Requires that you specify a file rotation type of <code>Size</code>.)

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_file_min_size => '500'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_file_min_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_file_name<a name='wls_jmsserver_log_file_name'>

The name of the file that stores current JMS server log messages. Usually it is a computed value based on the name of the parent of this MBean. For example, for a JMS server log, it is <code>jmsserverName.log</code>.  However, if the name of the parent cannot be obtained, the file name is <code>weblogic.log</code>. If you specify a relative pathname, it is interpreted as relative to the server's root directory.  To include a time and date stamp in the file name when the log file is rotated, add <code>java.text.SimpleDateFormat</code> variables to the file name. Surround each variable with percentage (<code>%</code>) characters.  For example, if the file name is defined to be <code>myjmsserver_%yyyy%_%MM%_%dd%_%hh%_%mm%.log</code>, the log file will be named <code>myserver_yyyy_mm_dd_hh_mm.log</code>.  When the log file is rotated, the rotated file name contains the date stamp. For example, if the log file is rotated on 2 April, 2005 at 10:05 AM, the log file that contains the old messages will be named <code>myserver_2005_04_02_10_05.log</code>.  If you do not include a time and date stamp, the rotated log files are numbered in order of creation. For example, <code>myjmsserver.log00007</code>.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_file_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_file_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_file_rotation_dir<a name='wls_jmsserver_log_file_rotation_dir'>

The directory where the rotated log files will be stored. By default the rotated files are stored in the same directory where the log file is stored.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_file_rotation_dir => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_file_rotation_dir']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_file_time_span<a name='wls_jmsserver_log_file_time_span'>

The interval (in hours) at which the server saves old log messages to another file. (Requires that you specify a file rotation type of <code>TIME</code>.)

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_file_time_span => '24'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_file_time_span']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_notes<a name='wls_jmsserver_log_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_number_of_files_limited<a name='wls_jmsserver_log_number_of_files_limited'>

Indicates whether to limit the number of log files that this server instance creates to store old messages. (Requires that you specify a file rotation type of <code>SIZE</code> or <code>TIME</code>.)  After the server reaches this limit, it deletes the oldest log file and creates a new log file with the latest suffix.  If you do not enable this option, the server creates new files indefinitely and you must clean up these files as you require.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_number_of_files_limited => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_number_of_files_limited']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### log_rotate_log_on_startup<a name='wls_jmsserver_log_rotate_log_on_startup'>

Specifies whether a server rotates its log file during its startup cycle. The default value in production mode is false.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_rotate_log_on_startup => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_rotate_log_on_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### log_rotation_time<a name='wls_jmsserver_log_rotation_time'>

Determines the start time (hour and minute) for a time-based rotation sequence.  At the time that this value specifies, the server renames the current log file. Thereafter, the server renames the log file at an interval that you specify in File Time Span.  Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.   Use the following format: <code>H:mm</code>, where <ul><li><code>H</code> is Hour in day (0-23). <li><code>mm</code> is the minute in hour </ul>

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_rotation_time => '00:00'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_rotation_time']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_rotation_type<a name='wls_jmsserver_log_rotation_type'>

Criteria for moving old log messages to a separate file. <ul> <li><code>NONE</code> Messages accumulate in a single file. You must erase the contents of the file when the size is too large. Note that WebLogic Server sets a threshold size limit of 500 MB before it forces a hard rotation to prevent excessive log file growth.  <li><code>SIZE</code> When the log file reaches the size that you specify in <code>FileMinSize</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>.  <li><code>TIME</code> At each time interval that you specify in <code>TimeSpan</code>, the server renames the file as <code>SERVER_NAME.lognnnnn</code>. </ul>  After the server renames a file, subsequent messages accumulate in a new file with the name that you specified as the log file name.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_rotation_type => 'bySize'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_rotation_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### log_tags<a name='wls_jmsserver_log_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       log_tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:log_tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### maximum_message_size<a name='wls_jmsserver_maximum_message_size'>

The maximum number of bytes allowed in individual messages on this JMS server. The size of a message includes the message body, any user-defined properties, and the user-defined JMS header fields <code>JMSCorrelationID</code> and <code>JMSType</code>.  The maximum message size is only enforced for the initial production of a message. Messages that are redirected to an error destination or forwarded to a member of a distributed destination are not checked for size. For instance, if a destination and its corresponding error destination are configured with a maximum message size of 128K bytes and 64K bytes, respectively, a message of 96K bytes could be redirected to the error destination (even though it exceeds the 64K byte maximum), but a producer could not directly send the 96K byte message to the error destination.  Note: Any change to this maximum affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       maximum_message_size => '2147483647'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:maximum_message_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### message_buffer_size<a name='wls_jmsserver_message_buffer_size'>

The amount of memory (in bytes) that this JMS server can use to store message bodies before it writes them to disk. When the JMS server writes the message bodies to disk, it clears them from memory.  A value of -1 (the default) specifies that the server will automatically determine a size based on the maximum heap size of the JVM. This default will be set to either one-third the maximum heap size, or 512 megabytes, whichever is smaller.  The larger the buffer, the more memory JMS will consume when many messages are waiting on queues or topics. Once the buffer is surpassed, JMS may write message bodies to the directory specified by PagingDirectory in an effort to reduce memory usage below this buffer.  Surpassing the buffer size does not stop the JMS server from accepting new messages. It is still possible to run out of memory if messages are arriving faster than they can be written to disk. Users with high messaging loads who wish to support the highest possible availability should consider setting a quota or setting a threshold and enabling flow control.  Paging is always supported.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       message_buffer_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:message_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### message_compression_options<a name='wls_jmsserver_message_compression_options'>

Specifies the type of message compression used when JMS message body compression is enabled for Persistent Stores and JMS Paging Stores. <ul> <li>Use <code>GZIP_DEFAULT_COMPRESSION</code> to enable message compression using the JDK GZIP API with <code>DEFAULT_COMPRESSION</code> level.</li> <li>Use <code>GZIP_BEST_COMPRESSION</code> to enable message compression using the JDK GZIP API with <code>BEST_COMPRESSION</code> level. <li>Use <code>GZIP_BEST_SPEED</code> to enable message compression using the JDK GZIP API with <code>BEST_SPEED</code> level. <li>Use <code>LZF</code> to enable message compression using Open Source LZF. </ul> This attribute should be used only when configuring a WebLogic domain in an Oracle Exalogic environment.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       message_compression_options => 'GZIP_DEFAULT_COMPRESSION'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:message_compression_options']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### messages_maximum<a name='wls_jmsserver_messages_maximum'>

The maximum number of messages that can be stored in this JMS server. A value of <code>-1</code> removes any WebLogic Server limits.  Because excessive message volume can cause memory saturation, Oracle recommends that this value corresponds to the total amount of system memory available after accounting for the rest of your application load.  Range of Values: &gt;= MessagesThresholdHigh.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       messages_maximum => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:messages_maximum']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### messages_paging_enabled<a name='wls_jmsserver_messages_paging_enabled'>

This parameter has been deprecated. Paging is always enabled. The "MessageBufferSize" parameter controls how much memory is used before paging kicks in.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       messages_paging_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:messages_paging_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### messages_threshold_high<a name='wls_jmsserver_messages_threshold_high'>

The upper threshold (number of messages stored in this JMS server) that triggers flow control and logging events. A value of <code>-1</code> disables the events for this JMS server.  If the number of messages exceeds this threshold, the triggered events are: <ul> <li> <code>Log Messages</code> - A message is logged on the server indicating a high threshold condition. </li> <li> <code>Flow Control</code> - If flow control is enabled, the JMS server becomes armed and instructs producers to begin decreasing their message flow. </li> </ul>  Range of Values: &lt;= MessagesMaximum; &gt;= MessagesThresholdLow.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       messages_threshold_high => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:messages_threshold_high']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### messages_threshold_low<a name='wls_jmsserver_messages_threshold_low'>

The lower threshold (number of messages stored in this JMS server) that triggers flow control and logging events. A value of <code>-1</code> disables the events for this JMS server.  If the number of messages falls below this threshold, the triggered events are: <ul> <li> <code>Log Messages</code> - A message is logged on the server indicating that the threshold condition has cleared. </li> <li> <code>Flow Control</code> - If flow control is enabled, the JMS server becomes disarmed and instructs producers to begin increasing their message flow. </li> </ul>  Note: This attribute is dynamically configurable.  Range of Values: &lt;= MessagesThresholdHigh

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       messages_threshold_low => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:messages_threshold_low']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### name<a name='wls_jmsserver_name'>

The name.



[Back to overview of wls_jmsserver](#attributes)

### notes<a name='wls_jmsserver_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### paging_block_size<a name='wls_jmsserver_paging_block_size'>

The smallest addressable block, in bytes, of a file. When a native <code>wlfileio</code> driver is available and the paging block size has not been configured by the user, the store selects the minimum OS specific value for unbuffered (direct) I/O, if it is within the range [512, 8192]. A paging store's block size does not change once the paging store creates its files. Changes to block size only take effect for new paging stores or after the current files have been deleted. See "Tuning the Persistent Store" in Performance and Tuning for Oracle WebLogic Server.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_block_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_block_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### paging_directory<a name='wls_jmsserver_paging_directory'>

 Specifies where message bodies are written when the size of the message bodies in the JMS server exceeds the message buffer size.  If unspecified, messages are written to the default <code>tmp</code> directory inside the <code>server-name</code> subdirectory of a domain's root directory. For example, <code>domain-name/servers/server-name/tmp</code>, where <code>domain-name</code> is the root directory of your domain.   For best performance, this directory should not be the same as the directory used by the JMS server's persistent store.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_directory => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_directory']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### paging_file_locking_enabled<a name='wls_jmsserver_paging_file_locking_enabled'>

Determines whether OS file locking is used.  When file locking protection is enabled, a store boot fails if another store instance already has opened the store files. Do not disable this setting unless you have procedures in place to prevent multiple store instances from opening the same file. File locking is not required but helps prevent corruption in the event that two same-named file store instances attempt to operate in the same directories. This setting applies to both primary and cache files.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_file_locking_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_file_locking_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### paging_io_buffer_size<a name='wls_jmsserver_paging_io_buffer_size'>

The I/O buffer size, in bytes, automatically rounded down to the nearest power of 2. <ul> <li>When a native <code>wlfileio</code> driver is available, the setting applies to off-heap (native) memory.</li> <li>When a native <code>wlfileio</code> driver is not available, the setting applies to JAVA heap memory.</li> <li>For the best runtime performance, Oracle recommends setting <code>PagingIOBufferSize</code> so that it is larger than the largest write (multiple concurrent store requests may be combined into a single write).</li> <li>See the JMS server runtime MBean attribute <code>PagingAllocatedIOBufferBytes</code> to find out the actual allocated off-heap (native) memory amount.</li> </ul>

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_io_buffer_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_io_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### paging_max_file_size<a name='wls_jmsserver_paging_max_file_size'>

The paging maximum file size, in bytes. <ul> <li>The <code>PagingMaxFileSize</code> value affects the number of files needed to accommodate a paging store of a particular size (number of files = paging store size/MaxFileSize rounded up).</li>  <li>A paging store automatically reuses space freed by deleted records and automatically expands individual files up to <code>PagingMaxFileSize</code> if there is not enough space for a new record. If there is no space left in exiting files for a new record, a paging store creates an additional file.</li>  <li> A small number of larger files is normally preferred over a large number of smaller files as each file allocates Window Buffer and file handles. </li>  <li> If <code>PagingMaxFileSize</code> is larger than 2^24 * <code>PagingBlockSize</code>, then <code>MaxFileSize</code> is ignored, and the value becomes 2^24 * <code>PagingBlockSize</code>. The default <code>PagingBlockSize</code> is 512, and 2^24 * 512 is 8 GB. </li> </ul> Oracle recommends not setting the Paging Max File Size above the default value of 1,342,177,280.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_max_file_size => '1342177280'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_max_file_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### paging_max_window_buffer_size<a name='wls_jmsserver_paging_max_window_buffer_size'>

The maximum amount of data, in bytes and rounded down to the nearest power of 2, mapped into the JVM's address space per paging store file. Applies only when a native <code>wlfileio</code> library is loaded.  A window buffer does not consume Java heap memory, but does consume off-heap (native) memory. If the paging store is unable to allocate the requested buffer size, it allocates smaller and smaller buffers until it reaches <code>PagingMinWindowBufferSize</code>, and then fails if it cannot honor <code>PagingMinWindowBufferSize</code>.  Oracle recommends setting the max window buffer size to more than double the size of the largest write (multiple concurrently updated records may be combined into a single write), and greater than or equal to the file size, unless there are other constraints. 32-bit JVMs may impose a total limit of between 2 and 4GB for combined Java heap plus off-heap (native) memory usage.  <ul> <li>See the JMS server runtime MBean attribute <code>PagingAllocatedWindowBufferBytes</code> to find out the actual allocated Window Buffer Size.<li>

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_max_window_buffer_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_max_window_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### paging_message_compression_enabled<a name='wls_jmsserver_paging_message_compression_enabled'>

Enables the JMS paging store to perform message body compression on persistent and non-persistent messages. When <code>false</code>, the default value, no compression is performed. This attribute should be enabled only when configuring a WebLogic domain in an Oracle Exalogic environment.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_message_compression_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_message_compression_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### paging_min_window_buffer_size<a name='wls_jmsserver_paging_min_window_buffer_size'>

The minimum amount of data, in bytes and rounded down to the nearest power of 2, mapped into the JVM's address space per paging store file.  Applies only when a native <code>wlfileio</code> library is loaded. See <a href='#getPagingMaxWindowBufferSize'>Paging Maximum Window Buffer Size</a>.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       paging_min_window_buffer_size => '-1'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:paging_min_window_buffer_size']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### persistent_store<a name='wls_jmsserver_persistent_store'>

The file or database in which this JMS server stores persistent messages. If unspecified, the JMS server uses the default persistent store that is configured on each targeted WebLogic Server instance. If the JMS server has a store configured, then the configured store is used to store persistent messages.  The disk-based file store or JDBC-accessible database store that you specify must be targeted to the same server, cluster, or migratable target instance as this JMS server. Multiple services on the same WebLogic Server instance, including multiple JMS servers, may share the same persistent store. Each service's persistent data will be kept apart.  If you specify a PersistentStore, the deprecated Store field must not be set. If neither the PersistentStore field nor the Store field are set, the JMS server supports persistent messaging using the default persistent store for the targeted WebLogic Server instance.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       persistent_store => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:persistent_store']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### persistentstore<a name='wls_jmsserver_persistentstore'>

The persistentstore name.



[Back to overview of wls_jmsserver](#attributes)

### persistentstoretype<a name='wls_jmsserver_persistentstoretype'>

The persistentstore type

Valid values are `FileStore`, `JDBCStore`. 

[Back to overview of wls_jmsserver](#attributes)

### production_paused_at_startup<a name='wls_jmsserver_production_paused_at_startup'>

Specifies whether production is paused at server startup on destinations targeted to this JMS server. A destination cannot receive any new messages while it is paused.  When the value is set to <code>true</code>, then immediately after the host server instance is rebooted, then this JMS server and its targeted destinations are modified such that they are in a "production paused" state, which results in preventing new message production activities on those destinations.  To resume normal new message production activity, later you will have to change the state of this JMS server to a "production enabled" state by setting this value to <code>false</code>, and then either redeploy the JMS server or reboot the hosting server instance.   When the value is set to <code>default</code>, then the Production Paused At Startup is determined based on the corresponding setting on the individual destination.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       production_paused_at_startup => 'default'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:production_paused_at_startup']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### provider<a name='wls_jmsserver_provider'>

The specific backend to use for this `wls_jmsserver`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: JMS server in an WebLogic domain via regular WLST



[Back to overview of wls_jmsserver](#attributes)

### store_enabled<a name='wls_jmsserver_store_enabled'>

Specifies whether message persistence is supported for this JMS server. only for wls 10.3

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### store_message_compression_enabled<a name='wls_jmsserver_store_message_compression_enabled'>

Enables the JMS store to perform message body compression. When set to <code>false</code>, the default value, no compression is performed. This attribute should be enabled only when configuring a WebLogic domain in an Oracle Exalogic environment.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       store_message_compression_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:store_message_compression_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_jmsserver](#attributes)

### tags<a name='wls_jmsserver_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### target<a name='wls_jmsserver_target'>

An array of target names.

The array of targets for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `target`, you'll also have to specify `targettype`. Here is an example on how you can specify a `target`.

    wls_coherence_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_jmsserver](#attributes)

### targettype<a name='wls_jmsserver_targettype'>

An array of target types.

The array of target types for this resource. A target can be a WebLogic Server, a WebLogic cluster, or a JMS Server.
When specifying a `targettype`, you'll also have to specify a `target`. Here is an example on how you can specify a `target`.

    wls_coherence_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }

here is an example on specifying the `target` and `targettype` for a regular WebLogic cluster:

    wls_cluster{ 'aCluster':
      ...
      target     => ['myServer','myCluster'],
      targettype => ['Server','Cluster'],
      ...
    }



[Back to overview of wls_jmsserver](#attributes)

### temporary_template_name<a name='wls_jmsserver_temporary_template_name'>

The name of a configured JMS template that this JMS server uses to create temporary destinations.  Entering a template name, requires you to specify the JMS module that contains this template. However, a template name cannot be specified if the Hosting Temporary Destinations field is disabled.  Note: If the specified JMS template provides persistent store values, they are ignored because temporary destinations do not support persistent messaging.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       temporary_template_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:temporary_template_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### temporary_template_resource<a name='wls_jmsserver_temporary_template_resource'>

The name of a JMS module that contains a template that this JMS server can use to create temporary destinations.  Entering a JMS module name requires you to specify a temporary template name. However, a module name cannot be specified if the Hosting Temporary Destinations field is disabled.

An example on how to use this:

    wls_jmsserver {a_wls_jmsserver :
       ...
       temporary_template_resource => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_jmsserver:temporary_template_resource']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_jmsserver](#attributes)

### timeout<a name='wls_jmsserver_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_jmsserver](#attributes)
