---
title: wls machine
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage machine in an WebLogic domain.

Here is an example on how you should use this:

    wls_machine { 'test2':
      ensure        => 'present',
      listenaddress => '10.10.10.10',
      listenport    => '5556',
      machinetype   => 'UnixMachine',
      nmtype        => 'SSL',
    }

In this example you are managing a machine in the default domain. When you want to
manage a machine in a specific domain, you can use:

    wls_machine { 'my_domain/test2':
      ensure        => 'present',
      listenaddress => '10.10.10.10',
      listenport    => '5556',
      machinetype   => 'UnixMachine',
      nmtype        => 'SSL',
    }

## Attributes



Attribute Name                                                | Short Description                                                                                                                          |
------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------ |
[adapter](#wls_machine_adapter)                               | Gets the node manager client adapter name_version when using a VMM adapter to connect to OVM or other VMM adapter providers
               |
[adapter_name](#wls_machine_adapter_name)                     | Gets the node manager client adapter name when using a VMM adapter to connect to OVM or other VMM adapters providers
                      |
[adapter_version](#wls_machine_adapter_version)               | Gets the node manager client adapter version when using a VMM adapter to connect to OVM or other VMM adapters providers
                   |
[addresses](#wls_machine_addresses)                           | The addresses by which this machine is known.                                                                                              |
[debug_enabled](#wls_machine_debug_enabled)                   | Specifies whether communication with this Node Manager needs to be debugged.                                                               |
[domain](#wls_machine_domain)                                 | With this parameter, you identify the domain, where your objects is in.                                                                    |
[ensure](#wls_machine_ensure)                                 | The basic property that the resource should be in.                                                                                         |
[installed_vmm_adapters](#wls_machine_installed_vmm_adapters) | Gets a list of the names and versions of the installed Virtual Machine Manager (VMM) adapters
                                             |
[listen_address](#wls_machine_listen_address)                 | The host name or IP address of the NodeManager for the server or clients on the server to use when connecting to the NodeManager instance. |
[listen_port](#wls_machine_listen_port)                       | The port number of the NodeManager for the server or clients on the server to use when connecting to the NodeManager instance.             |
[listenaddress](#wls_machine_listenaddress)                   | The listenaddress of the machine
                                                                                                          |
[listenport](#wls_machine_listenport)                         | The listenport of the machine
                                                                                                             |
[machine_name](#wls_machine_machine_name)                     | The machine name
                                                                                                                          |
[machinetype](#wls_machine_machinetype)                       | The machine type
                                                                                                                          |
[name](#wls_machine_name)                                     | The name.                                                                                                                                  |
[nm_type](#wls_machine_nm_type)                               | Returns the node manager type for the server or clients on the server to use when connecting to the NodeManager instance.                  |
[nmtype](#wls_machine_nmtype)                                 | The nmtype of the machine
                                                                                                                 |
[node_manager_home](#wls_machine_node_manager_home)           | Returns the node manager home directory that will be used to substitute for the shell command template
                                    |
[notes](#wls_machine_notes)                                   | Optional information that you can include to describe this configuration.                                                                  |
[password](#wls_machine_password)                             | The password used by a Node Manager client to connect to the underlying service to which the Node Manager client delegates operations.     |
[post_bind_gid](#wls_machine_post_bind_gid)                   | The UNIX group ID (GID) that a server running on this machine will run under after it has carried out all privileged startup actions.      |
[post_bind_gid_enabled](#wls_machine_post_bind_gid_enabled)   | Specifies whether a server running on this machine binds to a UNIX Group ID (GID) after it has carried out all privileged startup actions. |
[post_bind_uid](#wls_machine_post_bind_uid)                   | The UNIX user ID (UID) that a server running on this machine will run under after it has carried out all privileged startup actions.       |
[post_bind_uid_enabled](#wls_machine_post_bind_uid_enabled)   | Specifies whether a server running on this machine binds to a UNIX User ID (UID) after it has carried out all privileged startup actions.  |
[provider](#wls_machine_provider)                             | resource.                                                                                                                                  |
[shell_command](#wls_machine_shell_command)                   | Returns the local command line to use when invoking SSH or RSH node manager functions.                                                     |
[tags](#wls_machine_tags)                                     | Return all tags on this Configuration MBean
                                                                                               |
[timeout](#wls_machine_timeout)                               | Timeout for applying a resource.                                                                                                           |
[user_name](#wls_machine_user_name)                           | The Node Manager client user name used to connect to the underlying service to which the client delegates operations.                      |




### adapter<a name='wls_machine_adapter'>

Gets the node manager client adapter name_version when using a VMM adapter to connect to OVM or other VMM adapter providers

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       adapter => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:adapter']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### adapter_name<a name='wls_machine_adapter_name'>

Gets the node manager client adapter name when using a VMM adapter to connect to OVM or other VMM adapters providers

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       adapter_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:adapter_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### adapter_version<a name='wls_machine_adapter_version'>

Gets the node manager client adapter version when using a VMM adapter to connect to OVM or other VMM adapters providers

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       adapter_version => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:adapter_version']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### addresses<a name='wls_machine_addresses'>

The addresses by which this machine is known. May be either host names or literal IP addresses.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       addresses => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:addresses']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### debug_enabled<a name='wls_machine_debug_enabled'>

Specifies whether communication with this Node Manager needs to be debugged. When enabled, connections to the NodeManager from the server or clients on the server will result in more information sent to the server log.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       debug_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:debug_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_machine](#attributes)

### domain<a name='wls_machine_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_machine](#attributes)

### ensure<a name='wls_machine_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_machine](#attributes)

### installed_vmm_adapters<a name='wls_machine_installed_vmm_adapters'>

Gets a list of the names and versions of the installed Virtual Machine Manager (VMM) adapters

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       installed_vmm_adapters => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:installed_vmm_adapters']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### listen_address<a name='wls_machine_listen_address'>

The host name or IP address of the NodeManager for the server or clients on the server to use when connecting to the NodeManager instance.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       listen_address => 'localhost'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:listen_address']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### listen_port<a name='wls_machine_listen_port'>

The port number of the NodeManager for the server or clients on the server to use when connecting to the NodeManager instance.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       listen_port => '5556'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:listen_port']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### listenaddress<a name='wls_machine_listenaddress'>

The listenaddress of the machine



[Back to overview of wls_machine](#attributes)

### listenport<a name='wls_machine_listenport'>

The listenport of the machine



[Back to overview of wls_machine](#attributes)

### machine_name<a name='wls_machine_machine_name'>

The machine name



[Back to overview of wls_machine](#attributes)

### machinetype<a name='wls_machine_machinetype'>

The machine type

Valid values are `absent`, `Machine`, `UnixMachine`. 

[Back to overview of wls_machine](#attributes)

### name<a name='wls_machine_name'>

The name.



[Back to overview of wls_machine](#attributes)

### nm_type<a name='wls_machine_nm_type'>

Returns the node manager type for the server or clients on the server to use when connecting to the NodeManager instance.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       nm_type => 'SSL'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:nm_type']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### nmtype<a name='wls_machine_nmtype'>

The nmtype of the machine

Valid values are `absent`, `SSL`, `Plain`, `SSH`, `RSH`. 

[Back to overview of wls_machine](#attributes)

### node_manager_home<a name='wls_machine_node_manager_home'>

Returns the node manager home directory that will be used to substitute for the shell command template

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       node_manager_home => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:node_manager_home']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### notes<a name='wls_machine_notes'>

Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### password<a name='wls_machine_password'>

The password used by a Node Manager client to connect to the underlying service to which the Node Manager client delegates operations.  When you get the value of this attribute, WebLogic Server does the following: <ol> <li>Retrieves the value of the <code>PasswordEncrypted</code> attribute.</li> <li>Decrypts the value and returns the unencrypted password as a String.</li> </ol> When you set the value of this attribute, WebLogic Server does the following: <ol> <li>Encrypts the value.</li> <li>Sets the value of the <code>PasswordEncrypted</code> attribute to the encrypted value.</li> </ol> Caution: Using the (<code>Password</code>) attribute is a potential security risk because the String object (which contains the unencrypted password), remains in the JVM's memory until garbage collection removes it and the memory is reallocated. Depending on how memory is allocated in the JVM, a significant amount of time could pass before this unencrypted data is removed from memory. Therefore, you should use the <code>PasswordEncrypted()</code> attribute instead.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       password => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:password']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### post_bind_gid<a name='wls_machine_post_bind_gid'>

The UNIX group ID (GID) that a server running on this machine will run under after it has carried out all privileged startup actions. Otherwise, the server will continue to run under the group under which it was started.(Requires that you enable Post-Bind GID.)

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       post_bind_gid => 'nobody'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:post_bind_gid']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### post_bind_gid_enabled<a name='wls_machine_post_bind_gid_enabled'>

Specifies whether a server running on this machine binds to a UNIX Group ID (GID) after it has carried out all privileged startup actions.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       post_bind_gid_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:post_bind_gid_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_machine](#attributes)

### post_bind_uid<a name='wls_machine_post_bind_uid'>

The UNIX user ID (UID) that a server running on this machine will run under after it has carried out all privileged startup actions. Otherwise, the server will continue to run under the account under which it was started.(Requires that you enable Post-Bind UID.)

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       post_bind_uid => 'nobody'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:post_bind_uid']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### post_bind_uid_enabled<a name='wls_machine_post_bind_uid_enabled'>

Specifies whether a server running on this machine binds to a UNIX User ID (UID) after it has carried out all privileged startup actions.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       post_bind_uid_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:post_bind_uid_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_machine](#attributes)

### provider<a name='wls_machine_provider'>

The specific backend to use for this `wls_machine`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: Manage machine in an WebLogic domain via regular WLST



[Back to overview of wls_machine](#attributes)

### shell_command<a name='wls_machine_shell_command'>

Returns the local command line to use when invoking SSH or RSH node manager functions.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       shell_command => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:shell_command']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### tags<a name='wls_machine_tags'>

Return all tags on this Configuration MBean

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       tags => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:tags']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)

### timeout<a name='wls_machine_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_machine](#attributes)

### user_name<a name='wls_machine_user_name'>

The Node Manager client user name used to connect to the underlying service to which the client delegates operations.

An example on how to use this:

    wls_machine {a_wls_machine :
       ...
       user_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_machine:user_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_machine](#attributes)
