---
title: wls managedserver
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

control a managed server or cluster state like running,stop,restart

Type for managed server control like start, running, abort and stop a managed server or a cluster.
Also supports `subscribe` with `refreshonly` when you only want to execute the restart when something
has changed.

Here is an example on how you should use this:

    wls_managedserver{'JMSServer1_Wls1036:':
      ensure                    => 'running',   #running|start|abort|stop
      target                    => 'Server', #Server|Cluster
      server_name               => 'JMSServer1',
      domain_name               => hiera('domain_name'),
      os_user                   => hiera('wls_os_user'),
      weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
      weblogic_user             => hiera('wls_weblogic_user'),
      weblogic_password         => hiera('domain_wls_password'),
      jdk_home_dir              => hiera('wls_jdk_home_dir'),
      adminserver_address       => hiera('domain_adminserver_address'),
      adminserver_port          => hiera('domain_adminserver_port'),
    }

Here is an example with `refreshonly`. In this example, the restart will only be executed
when the domain `Wls1036`  is changed. A restart will be executed.

    wls_managedserver{'JMSServer1_Wls1036':
      ensure                    => 'restart',   #running|start|abort|stop
      target                    => 'Server',    #Server|Cluster
      server_name               => 'JMSServer1',
      domain_name               => hiera('domain_name'),
      os_user                   => hiera('wls_os_user'),
      weblogic_home_dir         => hiera('wls_weblogic_home_dir'),
      weblogic_user             => hiera('wls_weblogic_user'),
      weblogic_password         => hiera('domain_wls_password'),
      jdk_home_dir              => hiera('wls_jdk_home_dir'),
      adminserver_address       => hiera('domain_adminserver_address'),
      adminserver_port          => hiera('domain_adminserver_port'),
      refreshonly               => true,
      subscribe                 => Wls_domain['Wls1036'],
    }

## Attributes



Attribute Name                                                | Short Description                                         |
------------------------------------------------------------- | --------------------------------------------------------- |
[adminserver_address](#wls_managedserver_adminserver_address) | The adminserver address.                                  |
[adminserver_port](#wls_managedserver_adminserver_port)       | The adminserver port.                                     |
[domain_name](#wls_managedserver_domain_name)                 | The weblogic domain name.                                 |
[ensure](#wls_managedserver_ensure)                           | Whether to do something.                                  |
[jdk_home_dir](#wls_managedserver_jdk_home_dir)               | The jdk home dir.                                         |
[name](#wls_managedserver_name)                               | The title.                                                |
[os_user](#wls_managedserver_os_user)                         | The weblogic operating system user.                       |
[provider](#wls_managedserver_provider)                       | resource.                                                 |
[refreshonly](#wls_managedserver_refreshonly)                 | refresh mechanism for when a dependent object is changed. |
[server_name](#wls_managedserver_server_name)                 | The adminserver name.                                     |
[target](#wls_managedserver_target)                           | The weblogic type.                                        |
[weblogic_home_dir](#wls_managedserver_weblogic_home_dir)     | The weblogic home folder.                                 |
[weblogic_password](#wls_managedserver_weblogic_password)     | The weblogic user password.                               |
[weblogic_user](#wls_managedserver_weblogic_user)             | The weblogic user.                                        |




### adminserver_address<a name='wls_managedserver_adminserver_address'>

The adminserver address.



[Back to overview of wls_managedserver](#attributes)

### adminserver_port<a name='wls_managedserver_adminserver_port'>

The adminserver port.



[Back to overview of wls_managedserver](#attributes)

### domain_name<a name='wls_managedserver_domain_name'>

The weblogic domain name.



[Back to overview of wls_managedserver](#attributes)

### ensure<a name='wls_managedserver_ensure'>

Whether to do something.

Valid values are `start` (also called `running`), `stop` (also called `abort`). 

[Back to overview of wls_managedserver](#attributes)

### jdk_home_dir<a name='wls_managedserver_jdk_home_dir'>

The jdk home dir.



[Back to overview of wls_managedserver](#attributes)

### name<a name='wls_managedserver_name'>

The title.



[Back to overview of wls_managedserver](#attributes)

### os_user<a name='wls_managedserver_os_user'>

The weblogic operating system user.



[Back to overview of wls_managedserver](#attributes)

### provider<a name='wls_managedserver_provider'>

The specific backend to use for this `wls_managedserver`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

wls_managedserver
: 



[Back to overview of wls_managedserver](#attributes)

### refreshonly<a name='wls_managedserver_refreshonly'>

The command should only be run as a
refresh mechanism for when a dependent object is changed.

Valid values are `true`, `false`. 

[Back to overview of wls_managedserver](#attributes)

### server_name<a name='wls_managedserver_server_name'>

The adminserver name.



[Back to overview of wls_managedserver](#attributes)

### target<a name='wls_managedserver_target'>

The weblogic type.



[Back to overview of wls_managedserver](#attributes)

### weblogic_home_dir<a name='wls_managedserver_weblogic_home_dir'>

The weblogic home folder.



[Back to overview of wls_managedserver](#attributes)

### weblogic_password<a name='wls_managedserver_weblogic_password'>

The weblogic user password.



[Back to overview of wls_managedserver](#attributes)

### weblogic_user<a name='wls_managedserver_weblogic_user'>

The weblogic user.



[Back to overview of wls_managedserver](#attributes)
