---
title: wls saf imported destination
keywords: documentation
layout: documentation
sidebar: wls_config_sidebar
toc: false
---
## Overview

This resource allows you to manage a SAF imported destinations in a JMS Module of a WebLogic domain.

Here is an example on how you should use this:

    wls_saf_imported_destination { 'jmsClusterModule:SAFImportedDestinations-0':
      ensure               => 'present',
      defaulttargeting     => 1,
      errorhandling        => 'ErrorHandling-0',
      jndiprefix           => 'saf_',
      remotecontext        => 'RemoteSAFContext-0',
      timetolivedefault    => '1000000000',
      usetimetolivedefault => 1,,
    }

In this example you are managing a SAF imported destination in the default domain. When you want to
manage a SAF imported destination in a specific domain, you can use:

    wls_saf_imported_destination { 'my_domain/jmsClusterModule:SAFImportedDestinations-1':
      ensure               => 'present',
      defaulttargeting     => '0',
      jndiprefix           => 'saf2_',
      remotecontext        => 'RemoteSAFContext-1',
      subdeployment        => 'safServers',
      usetimetolivedefault => '0',
    }

## Attributes



Attribute Name                                                                             | Short Description                                                                                                                                                                    |
------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ |
[default_targeting_enabled](#wls_saf_imported_destination_default_targeting_enabled)       | Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.                                                         |
[defaulttargeting](#wls_saf_imported_destination_defaulttargeting)                         | default targeting enabled.                                                                                                                                                           |
[domain](#wls_saf_imported_destination_domain)                                             | With this parameter, you identify the domain, where your objects is in.                                                                                                              |
[ensure](#wls_saf_imported_destination_ensure)                                             | The basic property that the resource should be in.                                                                                                                                   |
[errorhandling](#wls_saf_imported_destination_errorhandling)                               | the SAF Error Handling of this SAF imported destination
                                                                                                                             |
[imported_destination_name](#wls_saf_imported_destination_imported_destination_name)       | SAF imported destination name
                                                                                                                                                       |
[jmsmodule](#wls_saf_imported_destination_jmsmodule)                                       | The JMS module name.                                                                                                                                                                 |
[jndi_prefix](#wls_saf_imported_destination_jndi_prefix)                                   | Specifies the string that will prefix the local JNDI name of a remote destination.                                                                                                   |
[jndiprefix](#wls_saf_imported_destination_jndiprefix)                                     | the SAF JNDI prefix of this SAF imported destination
                                                                                                                                |
[name](#wls_saf_imported_destination_name)                                                 | The name.                                                                                                                                                                            |
[notes](#wls_saf_imported_destination_notes)                                               | Optional information that you can include to describe this named JMS descriptor bean.                                                                                                |
[provider](#wls_saf_imported_destination_provider)                                         | resource.                                                                                                                                                                            |
[remotecontext](#wls_saf_imported_destination_remotecontext)                               | the SAF Remote Context of this SAF imported destination
                                                                                                                             |
[saf_error_handling](#wls_saf_imported_destination_saf_error_handling)                     | Specifies the error handling configuration used for the imported destinations.                                                                                                       |
[saf_remote_context](#wls_saf_imported_destination_saf_remote_context)                     | Specifies the remote context used for the imported destinations.                                                                                                                     |
[sub_deployment_name](#wls_saf_imported_destination_sub_deployment_name)                   | Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.                                                 |
[subdeployment](#wls_saf_imported_destination_subdeployment)                               | The subdeployment name.                                                                                                                                                              |
[time_to_live_default](#wls_saf_imported_destination_time_to_live_default)                 | Specifies the default Time-to-Live value (expiration time), in milliseconds, for imported JMS messages.                                                                              |
[timeout](#wls_saf_imported_destination_timeout)                                           | Timeout for applying a resource.                                                                                                                                                     |
[timetolivedefault](#wls_saf_imported_destination_timetolivedefault)                       | the SAF time to live default of this SAF imported destination
                                                                                                                       |
[unit_of_order_routing](#wls_saf_imported_destination_unit_of_order_routing)               | Specifies the type of routing used to find a SAF agent when using the message Unit-of-Order feature.                                                                                 |
[use_saf_time_to_live_default](#wls_saf_imported_destination_use_saf_time_to_live_default) | Controls whether the Time-to-Live (expiration time) value set on imported JMS messages will be overridden by the value specified in the <code>SAF Default Time-to-Live</code> field. |
[usetimetolivedefault](#wls_saf_imported_destination_usetimetolivedefault)                 | use time to live default of this SAF imported destination
                                                                                                                           |




### default_targeting_enabled<a name='wls_saf_imported_destination_default_targeting_enabled'>

Specifies whether this JMS resource defaults to the parent module's targeting or uses the subdeployment targeting mechanism.  When set to true, this resource implicitly inherits the targeting of its parent module. When set to false, this resource gets targeted based its subdeployment's targets, if one is specified.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       default_targeting_enabled => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:default_targeting_enabled']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_saf_imported_destination](#attributes)

### defaulttargeting<a name='wls_saf_imported_destination_defaulttargeting'>

default targeting enabled.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_saf_imported_destination](#attributes)

### domain<a name='wls_saf_imported_destination_domain'>

With this parameter, you identify the domain, where your objects is in.

The domain name is part of the full qualified name of any WebLogic object on a system. Let's
say we want to describe a WebLogic server. The full qualified name is:

    wls_server{'domain_name/server_name':
      ensure => present,
      ...
    }

When you don't specify a domain name, Puppet will use `default` as domain name. For every domain
you want to manage, you'll have to put a `wls_settings` in your manifest.



[Back to overview of wls_saf_imported_destination](#attributes)

### ensure<a name='wls_saf_imported_destination_ensure'>

The basic property that the resource should be in.

Valid values are `present`, `absent`. 

[Back to overview of wls_saf_imported_destination](#attributes)

### errorhandling<a name='wls_saf_imported_destination_errorhandling'>

the SAF Error Handling of this SAF imported destination



[Back to overview of wls_saf_imported_destination](#attributes)

### imported_destination_name<a name='wls_saf_imported_destination_imported_destination_name'>

SAF imported destination name



[Back to overview of wls_saf_imported_destination](#attributes)

### jmsmodule<a name='wls_saf_imported_destination_jmsmodule'>

The JMS module name.



[Back to overview of wls_saf_imported_destination](#attributes)

### jndi_prefix<a name='wls_saf_imported_destination_jndi_prefix'>

Specifies the string that will prefix the local JNDI name of a remote destination.  Any change to this prefix affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       jndi_prefix => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:jndi_prefix']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### jndiprefix<a name='wls_saf_imported_destination_jndiprefix'>

the SAF JNDI prefix of this SAF imported destination



[Back to overview of wls_saf_imported_destination](#attributes)

### name<a name='wls_saf_imported_destination_name'>

The name.



[Back to overview of wls_saf_imported_destination](#attributes)

### notes<a name='wls_saf_imported_destination_notes'>

Optional information that you can include to describe this named JMS descriptor bean.  JMS module saves this note in the JMS descriptor file as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       notes => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:notes']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### provider<a name='wls_saf_imported_destination_provider'>

The specific backend to use for this `wls_saf_imported_destination`
resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.Available providers are:

simple
: saf imported destination in a JMS module of an WebLogic domain via regular WLST



[Back to overview of wls_saf_imported_destination](#attributes)

### remotecontext<a name='wls_saf_imported_destination_remotecontext'>

the SAF Remote Context of this SAF imported destination



[Back to overview of wls_saf_imported_destination](#attributes)

### saf_error_handling<a name='wls_saf_imported_destination_saf_error_handling'>

Specifies the error handling configuration used for the imported destinations.  Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       saf_error_handling => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:saf_error_handling']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### saf_remote_context<a name='wls_saf_imported_destination_saf_remote_context'>

Specifies the remote context used for the imported destinations.  Changing the remote context name affects both stored messages and incoming messages.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       saf_remote_context => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:saf_remote_context']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### sub_deployment_name<a name='wls_saf_imported_destination_sub_deployment_name'>

Gets the name of the sub-deployment to use when targeting this entity   Entities are targeted using a sub-deployment with this name.  The targets of the sub-deployment will be the targets of this entity.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       sub_deployment_name => 'a_value'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:sub_deployment_name']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### subdeployment<a name='wls_saf_imported_destination_subdeployment'>

The subdeployment name.



[Back to overview of wls_saf_imported_destination](#attributes)

### time_to_live_default<a name='wls_saf_imported_destination_time_to_live_default'>

Specifies the default Time-to-Live value (expiration time), in milliseconds, for imported JMS messages. The expiration time set on JMS messages will override this value unless the <code>SAF Default Time-to-Live Enabled</code> field is switched on, which then overrides the expiration time in JMS messages on imported destinations.  Any change to this value affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       time_to_live_default => '3600000'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:time_to_live_default']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### timeout<a name='wls_saf_imported_destination_timeout'>

Timeout for applying a resource.

To be sure no Puppet operation, hangs a Puppet daemon, all operations have a timeout. When this timeout
expires, Puppet will abort the current operation and signal an error in the Puppet run.

With this parameter, you can specify the length of the timeout. The value is specified in seconds. In
this example, the `timeout`  is set to `600`  seconds.

    wls_server{'my_server':
      ...
      timeout => 600,
    }

The default value for `timeout` is 120 seconds.



[Back to overview of wls_saf_imported_destination](#attributes)

### timetolivedefault<a name='wls_saf_imported_destination_timetolivedefault'>

the SAF time to live default of this SAF imported destination



[Back to overview of wls_saf_imported_destination](#attributes)

### unit_of_order_routing<a name='wls_saf_imported_destination_unit_of_order_routing'>

Specifies the type of routing used to find a SAF agent when using the message Unit-of-Order feature.  <ul> <li><code>Hash</code> indicates that message producers use the hash code of a message Unit-of-Order to find a SAF agent. </li>  <li><code>PathService</code> indicates that message producers use the Path Service to find a SAF agent. </li> </ul>

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       unit_of_order_routing => 'Hash'
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:unit_of_order_routing']
       ...
    }

This help text generated from MBean text of the WebLogic server.



[Back to overview of wls_saf_imported_destination](#attributes)

### use_saf_time_to_live_default<a name='wls_saf_imported_destination_use_saf_time_to_live_default'>

Controls whether the Time-to-Live (expiration time) value set on imported JMS messages will be overridden by the value specified in the <code>SAF Default Time-to-Live</code> field.  Any change to this parameter affects only incoming messages; stored messages are not affected.

An example on how to use this:

    wls_saf_imported_destination {a_wls_saf_imported_destination :
       ...
       use_saf_time_to_live_default => 1,
       ...
    }

This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

    wls_setting{'domain':
       ...
      extra_properties => ['wls_saf_imported_destination:use_saf_time_to_live_default']
       ...
    }

This help text generated from MBean text of the WebLogic server.

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_saf_imported_destination](#attributes)

### usetimetolivedefault<a name='wls_saf_imported_destination_usetimetolivedefault'>

use time to live default of this SAF imported destination

Valid values are `absent`, `1`, `0`. 

[Back to overview of wls_saf_imported_destination](#attributes)
