#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_clusterwide_recovery_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Indicates that cluster-wide recovery is used for distributed transactions.  When enabled, recovery operations for a distributed transaction are applied to all the servers of the cluster hosting a InterposedTransactionManager rather than just the server hosting the InterposedTransactionManager. 

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         jta_clusterwide_recovery_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:jta_clusterwide_recovery_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JTACluster/%{cluster_name}/ClusterwideRecoveryEnabled')
end
