#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:secure_replication_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Servers in a cluster replicate session data. If a replication channel is defined then the session data will be sent using the replication channel protocol and secured replication settings will be ignored. If no replication channel is defined and secured replication is enabled then session data for in-memory replication will be sent over SSL using the default secured channel. However, this added security for replication traffic comes with a significant cluster performance degradation. It should only be enabled if security is of greater concern than performance degradation. 

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         secure_replication_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:secure_replication_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD


  maps_to('SecureReplicationEnabled')
end
