#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:xa_keep_xa_conn_till_tx_complete, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Enables WebLogic Server to associate the same XA database connection from the connection pool with a global transaction until the transaction completes.  Only applies to connection pools that use an XA driver.  Use this setting to work around specific problems with JDBC XA drivers. 

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         xa_keep_xa_conn_till_tx_complete => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:xa_keep_xa_conn_till_tx_complete']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('JDBCResource/%{datasource_name}/JDBCXAParams/%{datasource_name}/KeepXaConnTillTxComplete')
end
