#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:mincapacity, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer
  

  desc <<-EOD
    The min capacity of the datasource.

  EOD

  defaultto '1'

  maps_to('JDBCResource/%{datasource_name}/JDBCConnectionPoolParams/%{datasource_name}/MinCapacity')


  on_apply do
    #
    # If the minimum capacity will be changed to a value that is higher then the current maxmiumcapacity
    # WebLogic will return an error. To fix this, when this situation arrises, we need to set the value of mincapacity first
    #
    if resource.provider.maxcapacity != :absent && value > resource.provider.maxcapacity.to_i
      Puppet.debug('First setting maxcapacity because requested mincapacity is higher then current maxcapacity')
      key = 'JDBCResource/%{datasource_name}/JDBCConnectionPoolParams/%{datasource_name}/MaxCapacity'
      path = "#{type_path}/#{resource[key_name]}/#{key}" % resource.to_hash
      wls_config.set(path, resource[:maxcapacity])
      #
      # To make sure WebLogic knows about it. Save it. Because the other properties expect an edit mode, restart the edit mode
      #
      wls_config.save
      wls_config.edit
    end
    super()
  end

end
