#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:diagnostic_context_compatibility_mode_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-EOD
  Specifies whether WLDF sends a pre-12.2.1-style diagnostic context along with the current-style diagnostic context.  If outbound communication to pre-12.2.1 servers is possible, this setting should always be enabled to ensure that those servers receive a diagnostic context that they can process. Disabling this setting in those scenarios can result in correlation information being lost across tiers, and in information reported by WLDF and DMS to become of sync in some situations.  If there is no outbound communication to pre-12.2.1 servers possible, it is suggested to disable this mode as only the current-style diagnostic context is needed to be propagated outbound (propagating the old style will not cause a failure, but is unnecessary overhead in that situation).  This setting affects outbound only, inbound pre-12.2.1 style diagnostic contexts are always understood and handled. 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         diagnostic_context_compatibility_mode_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:diagnostic_context_compatibility_mode_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DiagnosticContextCompatibilityModeEnabled')
end
