#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_platform_logger_levels, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-EOD
  Specifies the platform logger and the associated level names set through the WebLogic Server configuration.  Note the following behavior: <ul> <li>The configuration is applicable for <code>java.util.logging.Logger</code> instances in the JDK's default global LogManager.</li> <li>WebLogic Server loggers are configured in terms of <code>weblogic.logging.Severities</code> through the <code>LoggerSeverities</code> attribute. These loggers are not available in the JDK's default global LogManager.</li> </ul> 

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         log_platform_logger_levels => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:log_platform_logger_levels']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('Log/%{domain_name}/PlatformLoggerLevels')
end
