#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_default_time_to_live, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The maximum length of time, in milliseconds, that a message exists. This value is used for messages when both the `time-to-live` is not explicitly set by the sender application that is using this connection factory and the `time-to-live` is not explicitly overridden by the destination's `TimeToLiveOverride` attribute . A value of 0 indicates that the message has an infinite amount time to live.   Message producer applications can set the `time-to-live` explicitly by calling the standard JMS `javax.jms.MessageProducer.setTimeToLive(long)` method. Note that programmatically setting `time-to-live` using `javax.jms.Message.setJMSExpiration()` has no effect - the message setter is ignored by  the JMS send call as required by the JMS specification.   This attribute is dynamic. It can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory. 

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         delivery_default_time_to_live => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:delivery_default_time_to_live']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('DefaultDeliveryParams/%{connection_factory_name}/DefaultTimeToLive')
end
