#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:paging_file_locking_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Determines whether OS file locking is used.  When file locking protection is enabled, a store boot fails if another store instance already has opened the store files. Do not disable this setting unless you have procedures in place to prevent multiple store instances from opening the same file. File locking is not required but helps prevent corruption in the event that two same-named file store instances attempt to operate in the same directories. This setting applies to both primary and cache files. 

  An example on how to use this:

      wls_jmsserver {a_wls_jmsserver :
         ...
         paging_file_locking_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jmsserver:paging_file_locking_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('PagingFileLockingEnabled')
end
