#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:message_buffer_size, :parent => Puppet::Parameter::WlsProperty) do
  

  desc <<-EOD
  The amount of memory used to store message bodies in memory before they are paged out to disk. <ul> <li> A value of -1 (the default) specifies that the server will automatically determine a size based on the maximum heap size of the JVM. This default will be set to either one-third the maximum heap size, or 512 megabytes, whichever is smaller. </li>  <li> The larger the buffer, the more memory JMS will consume when many messages are waiting on queues or topics. Once the buffer is surpassed, JMS may write message bodies to the directory specified by PagingDirectory in an effort to reduce memory usage below this buffer. </li>  <li> Surpassing the buffer size does not stop the JMS server from accepting new messages. It is still possible to run out of memory if messages are arriving faster than they can be written to disk. Users with high messaging loads who wish to support the highest possible availability should consider setting a quota or setting a threshold and enabling flow control. </li>  <li> Applies only to agents with sending capability. </li>  <li> Paging is always supported.  </li>  <li> Updating the memory size resets the message count so that only requests arriving after the update are charged against the new memory size. </li> </ul> 

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         message_buffer_size => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:message_buffer_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  maps_to('MessageBufferSize')
end
