#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_redirect_stderr_to_server_log_enabled, :parent => Puppet::Parameter::WlsProperty) do

  desc <<-EOD
  Specifies whether the stderr of the JVM in which a WebLogic Server instance runs is redirected to the WebLogic Logging system. When this attribute is enabled, the stderr content is published to all the registered log destinations, such as the server terminal console and log file.  Note that JVM messages are redirected asynchronously. In the event of an overload situation, these messages may be dropped. As a best practice, Oracle recommends using one of the supported logging APIs instead. 

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         log_redirect_stderr_to_server_log_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:log_redirect_stderr_to_server_log_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  EOD

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('Log/%{template_name}/RedirectStderrToServerLogEnabled')
end
